@@ -1,5 +1,6 @@
 use cuppa::database::DataBase;
-use serde_json::{json, Result};
+use cuppa::utils;
+use serde_json::{Result};
 use serde::{Serialize, Deserialize};
 
 
@@ -10,13 +11,13 @@ struct User{
 }
 
 fn main_async() -> Result<()>{
-    
     let db = DataBase::new("localhost", 3306, "rust", "root", "");
     let row = db.get_row("users".to_string(), "id = 1".to_string(), "".to_string(), "".to_string());
-    if row.is_err() { return Ok(()); }
-    let row = row.unwrap();
-    let user:User = serde_json::from_value(json!(row))?;
-    println!("{:?}", user);
+    if row.is_ok(){
+        let user:User = utils::map_to_struct(row.unwrap())?;
+        println!("USER {:?}", user);
+    }
+    
     Ok(())
 }
 
