@@ -2,8 +2,8 @@
     [dependencies]
     serde_json = "1.0.64"
 */
-use serde_json::{Result, Value};
-
+use serde_json::{json, Result, Value, Map};
+use serde::de::DeserializeOwned;
 /// # Example:
 ///
 /// ```
@@ -14,3 +14,11 @@ pub fn json_decode(string:&str) -> Result<Value> {
     let result: Value = serde_json::from_str(string)?;
     Ok(result)
 }
+
+pub fn map_to_struct<T>(map:Map<String, Value>) -> Result<T>
+    where
+        T: DeserializeOwned,
+{
+    let value:Value = json!(map);
+    T::deserialize(value)
+}
\ No newline at end of file
